aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/data/python/ops/sliding.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/contrib/data/python/ops/sliding.py')
-rw-r--r--tensorflow/contrib/data/python/ops/sliding.py69
1 files changed, 49 insertions, 20 deletions
diff --git a/tensorflow/contrib/data/python/ops/sliding.py b/tensorflow/contrib/data/python/ops/sliding.py
index 3f3c5ca17c..e9dd74530a 100644
--- a/tensorflow/contrib/data/python/ops/sliding.py
+++ b/tensorflow/contrib/data/python/ops/sliding.py
@@ -23,25 +23,29 @@ from tensorflow.python.framework import dtypes
from tensorflow.python.framework import ops
from tensorflow.python.framework import tensor_shape
from tensorflow.python.ops import gen_dataset_ops
+from tensorflow.python.util import deprecation
class _SlideDataset(dataset_ops.Dataset):
"""A `Dataset` that passes a sliding window over its input."""
- def __init__(self, input_dataset, window_size, stride=1):
+ def __init__(self, input_dataset, window_size, window_shift, window_stride):
"""See `sliding_window_batch` for details."""
super(_SlideDataset, self).__init__()
self._input_dataset = input_dataset
self._window_size = ops.convert_to_tensor(
- window_size, dtype=dtypes.int64, name="window_size")
- self._stride = ops.convert_to_tensor(
- stride, dtype=dtypes.int64, name="stride")
+ window_size, dtype=dtypes.int64, name="window_stride")
+ self._window_stride = ops.convert_to_tensor(
+ window_stride, dtype=dtypes.int64, name="window_stride")
+ self._window_shift = ops.convert_to_tensor(
+ window_shift, dtype=dtypes.int64, name="window_shift")
def _as_variant_tensor(self):
return gen_dataset_ops.slide_dataset(
self._input_dataset._as_variant_tensor(), # pylint: disable=protected-access
window_size=self._window_size,
- stride=self._stride,
+ window_shift=self._window_shift,
+ window_stride=self._window_stride,
**dataset_ops.flat_structure(self))
@property
@@ -61,38 +65,63 @@ class _SlideDataset(dataset_ops.Dataset):
return self._input_dataset.output_types
-def sliding_window_batch(window_size, stride=1):
- """A sliding window with size of `window_size` and step of `stride`.
+@deprecation.deprecated_args(
+ None, "stride is deprecated, use window_shift instead", "stride")
+def sliding_window_batch(window_size,
+ stride=None,
+ window_shift=None,
+ window_stride=1):
+ """A sliding window over a dataset.
- This transformation passes a sliding window over this dataset. The
- window size is `window_size` and step size is `stride`. If the left
- elements cannot fill up the sliding window, this transformation will
- drop the final smaller element. For example:
+ This transformation passes a sliding window over this dataset. The window size
+ is `window_size`, the stride of the input elements is `window_stride`, and the
+ shift between consecutive windows is `window_shift`. If the remaining elements
+ cannot fill up the sliding window, this transformation will drop the final
+ smaller element. For example:
```python
# NOTE: The following examples use `{ ... }` to represent the
# contents of a dataset.
a = { [1], [2], [3], [4], [5], [6] }
- a.apply(tf.contrib.data.sliding_window_batch(window_size=3, stride=2)) ==
- {
- [[1], [2], [3]],
- [[3], [4], [5]],
- }
+ a.apply(sliding_window_batch(window_size=3)) ==
+ { [[1], [2], [3]], [[2], [3], [4]], [[3], [4], [5]], [[4], [5], [6]] }
+
+ a.apply(sliding_window_batch(window_size=3, window_shift=2)) ==
+ { [[1], [2], [3]], [[3], [4], [5]] }
+
+ a.apply(sliding_window_batch(window_size=3, window_stride=2)) ==
+ { [[1], [3], [5]], [[2], [4], [6]] }
```
Args:
window_size: A `tf.int64` scalar `tf.Tensor`, representing the number of
elements in the sliding window.
stride: (Optional.) A `tf.int64` scalar `tf.Tensor`, representing the
- steps moving the sliding window forward for one iteration. The default
- is `1`. It must be positive.
+ forward shift of the sliding window in each iteration. The default is `1`.
+ It must be positive. Deprecated alias for `window_shift`.
+ window_shift: (Optional.) A `tf.int64` scalar `tf.Tensor`, representing the
+ forward shift of the sliding window in each iteration. The default is `1`.
+ It must be positive.
+ window_stride: (Optional.) A `tf.int64` scalar `tf.Tensor`, representing the
+ stride of the input elements in the sliding window. The default is `1`.
+ It must be positive.
Returns:
A `Dataset` transformation function, which can be passed to
@{tf.data.Dataset.apply}.
+
+ Raises:
+ ValueError: if invalid arguments are provided.
"""
+ if stride is None and window_shift is None:
+ window_shift = 1
+ elif stride is not None and window_shift is None:
+ window_shift = stride
+ elif stride is not None and window_shift is not None:
+ raise ValueError("Cannot specify both `stride` and `window_shift`")
+
def _apply_fn(dataset):
- return _SlideDataset(dataset, window_size, stride)
+ return _SlideDataset(dataset, window_size, window_shift, window_stride)
return _apply_fn
@@ -61,38 +65,63 @@ class _SlideDataset(dataset_ops.Dataset):
Args:
window_size: A `tf.int64` scalar `tf.Tensor`, representing the number of
- elements in the sliding window.
+ elements in the sliding window. It must be positive.
stride: (Optional.) A `tf.int64` scalar `tf.Tensor`, representing the